#!/bin/sh

. tables.sh

BASE_DELAY=30

# Show the cursor.  Call before exiting.
show_cursor()
{
    printf "%s" "$ESC[?25h"                           # show cursor
}

# Hide the cursor.  Call regularly.
hide_cursor()
{
    printf "%s" "$ESC[?25l"                           # hide cursor
}

# Resets the display and configures various settings.
vtreset()
{
    printf "%s" "$ESCc"                               # VT100 reset
    printf "%s" "$ESC[?71"                            # Turn off auto-wrap
    echo ; echo ""                            # clear screen
    hide_cursor
}

# Sets the cursor to a given row and column.
vtsetpos()
{
    local VTS_ROW=$1
    local VTS_COL=$2

    # echo "ROW: '$VTS_ROW' COL: '$VTS_COL'"

    printf "%s" "$ESC["
    printf "%s" "$VTS_ROW"
    printf "%s" ";"
    printf "%s" "$VTS_COL"
    printf "%s" "H"
    hide_cursor
}

# VT100 Commands

ESC=`printf "\e"`

# Set

# Options
SET="$ESC["
BOOLEAN="?"
SHOWHIDE=25
HIDDEN=l
VISIBLE=h

# Colors
FOREGROUND=3
BACKGROUND=4

BLACK=0
RED=1
GREEN=2
YELLOW=3
BLUE=4
MAGENTA=5
CYAN=6
WHITE=7
ORANGE=8 # Not a real color, but some special draw routines like in shelltris use it as a trick.
DEFAULT=9

# Attributes
INVERSE=7
UNDERLINE=4
BOLD=1

ENABLE=0
DISABLE=2

ATTRIBUTE="m"


function boom1()
{
	local X=$1
	local Y=$2
	local MAX_EXPLOSION_DIAMETER=$3
	local SIZE=$4
	local COLOR=$5
	local TYPE=$6

	# echo "X: $X Y: $Y ED: $MAX_EXPLOSION_DIAMETER C: $COUNT"

	local BRIGHTNESS=10
	local MINBRIGHT="$(eval echo "\$$TYPE""_D$MAXSIZE""_MINBRIGHT")"

	if [ $SIZE -gt $(( $MAX_EXPLOSION_DIAMETER + (10 - $MINBRIGHT) )) ] ; then
		BRIGHTNESS="C"
		SIZE=$MAX_EXPLOSION_DIAMETER
	elif [ $SIZE -gt $MAX_EXPLOSION_DIAMETER ] ; then
		BRIGHTNESS=$((10 - ($SIZE -$MAX_EXPLOSION_DIAMETER)))
		SIZE=$MAX_EXPLOSION_DIAMETER
	fi

	HCENTER="$(eval echo "\$$TYPE""_D$SIZE""_HCENTER")"
	VCENTER="$(eval echo "\$$TYPE""_D$SIZE""_VCENTER")"
	MAX="$(eval "echo \"\$$TYPE""_D$SIZE""_MAX\"")"

	# echo "MAX: $MAX"
	# echo "BD10: $BALL_D10_MAX"

	local HPOS=$(($X - HCENTER + 1))
	local VPOS=$(($Y - VCENTER + 1))

	local i=1;

	# echo "I: \"$i\" MAX: \"$MAX\" ED: \"$MAX_EXPLOSION_DIAMETER\"";
	# echo "SIZE: $SIZE BRIGHTNESS: $BRIGHTNESS" >> /tmp/fireworks_log

	echo "$SET$FOREGROUND$COLOR$ATTRIBUTE"

	while [ $i -le $MAX ] ; do
		LINE="$(eval echo "\"\$$TYPE""_D$SIZE""_B$BRIGHTNESS""_LINE$i\"")"
		# echo "LINE"
		vtsetpos $(($VPOS + $i)) $HPOS
		printf "%s" "$LINE"
		i=$(($i + 1))
	done
	echo "$SET$FOREGROUND$DEFAULT$ATTRIBUTE"

}


if [ "x$DO_MAIN" = "x" ] ; then
	echo "Testing boom.sh"

#        local X=$1
#        local Y=$2
#        local MAX_EXPLOSION_DIAMETER=$3
#        local SIZE=$5

	# Center X,Y
	X=10
	Y=10

	# MAXSIZE=9
	# MINBRIGHT="$(eval echo "\$BALL_D$MAXSIZE""_MINBRIGHT")"

	clear

	j=0
	while [ $j -le 13 ] ; do
		MAXSIZE=$j

		if [ $j -eq 13 ] ; then
			MAXSIZE=16
			TYPE="CIRCLES"
			DELAY=$(($BASE_DELAY * 3))
		elif [ $j -eq 12 ] ; then
			MAXSIZE=11
			TYPE="STREAMER"
			DELAY=$(($BASE_DELAY * 2))
		else
			TYPE="BALL"
			DELAY=$BASE_DELAY
		fi
		# echo "\$$TYPE""_D$MAXSIZE""_MINBRIGHT" >> /tmp/fireworks_log
		MINBRIGHT="$(eval echo "\$$TYPE""_D$MAXSIZE""_MINBRIGHT")"
		vtsetpos 1 1

		COLOR=$((($j % 6) + 1))

		echo "SIZE: $MAXSIZE COLOR: $COLOR TYPE: $TYPE"

		i=0
		while [ $i -le $(( $MAXSIZE + 11 - $MINBRIGHT)) ] ; do
			boom1 $X $Y $MAXSIZE $i $COLOR $TYPE
			i=$(($i + 1))

			k=0
			while [ $k -le $DELAY ] ; do
				CH="$(./getch)"
				k=$(($k + 1))
			done
			# sleep 1
		done
		# sleep 5
		j=$(($j + 1))
	done

fi

